﻿using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;
using Telerik.Windows.Controls;
using System.Linq;
using Telerik.Windows.Diagrams.Core;

namespace BaseApplicationProject
{
    public partial class MainWindow : Window
    {
        private HitTestService hitTestService;
        private SelectionService selectionService;

        public MainWindow()
        {
            InitializeComponent();

            this.AddHandler(RadDiagram.KeyDownEvent, new KeyEventHandler(OnKeyDown), true);

            hitTestService = this.diagram.ServiceLocator.GetService<IHitTestService>() as HitTestService;
            selectionService = this.diagram.ServiceLocator.GetService<ISelectionService<IDiagramItem>>() as SelectionService;
        }
        private void OnKeyDown(object sender, KeyEventArgs args)
        {
            bool isShiftKeyDown = (args.Key == Key.LeftShift || args.Key == Key.RightShift);
            bool isLeftMouseButtonDown = Mouse.LeftButton == MouseButtonState.Pressed;

            if (isShiftKeyDown && isLeftMouseButtonDown )
            { 
                this.selectionService.SelectItem(this.hitTestService.ItemUnderMouse, true);
            }
        }

        private void diagram_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            bool isShiftKeyDown = Keyboard.IsKeyDown(Key.LeftShift) || Keyboard.IsKeyDown(Key.RightShift);
            if (isShiftKeyDown)
            {
                var shapes = hitTestService.GetShapesUnderRect(diagram.SelectionBounds);

                foreach (RadDiagramShape shape in shapes)
                {
                    shape.IsSelected = true;
                }
            }
        }

        private void diagram_PreviewSelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            bool isShiftKeyDown = Keyboard.IsKeyDown(Key.LeftShift) || Keyboard.IsKeyDown(Key.RightShift);
            if (isShiftKeyDown && e.RemovedItems.Count != 0)
                e.Handled = true;
        }
    }
}
